==> opennms-33.1.5-source.tar.gz: opennms-33.1.5/core/web-assets/src/main/assets/js/lib/onms-http/ErrorResponse.js <==
/*
 * Licensed to The OpenNMS Group, Inc (TOG) under one or more
 * contributor license agreements.  See the LICENSE.md file
 * distributed with this work for additional information
 * regarding copyright ownership.
 *
 * TOG licenses this file to You under the GNU Affero General
 * Public License Version 3 (the "License") or (at your option)
 * any later version.  You may not use this file except in
 * compliance with the License.  You may obtain a copy of the
 * License at:
 *
 *      https://www.gnu.org/licenses/agpl-3.0.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.  See the License for the specific
 * language governing permissions and limitations under the
 * License.
 */
import ContextError from "./ContextError";

export default class ErrorResponse {

    constructor(response) {
        this.response = response;
    }

    get status() {
        return this.response.status;
    }

    isContextError() {
        return this.response.data && this.response.data.context && this.response.data.message;
    }

    asContextError() {
        if (this.isContextError()) {
            return new ContextError(this.response.data.context, this.response.data.message);
        }
        if (this.response.data && this.response.data.message) {
            return new ContextError('entity', this.response.data.message);
        }
        return new ContextError('entity', 'Unexpected error occurred. No details about the nature of the error were provided');
    }

    isBadRequest() {
        return this.status === 400;
    }
}

==> opennms-35.0.0-source.tar.gz: opennms-35.0.0/core/web-assets/src/main/assets/js/lib/onms-http/ErrorResponse.js <==
/*
 * Licensed to The OpenNMS Group, Inc (TOG) under one or more
 * contributor license agreements.  See the LICENSE.md file
 * distributed with this work for additional information
 * regarding copyright ownership.
 *
 * TOG licenses this file to You under the GNU Affero General
 * Public License Version 3 (the "License") or (at your option)
 * any later version.  You may not use this file except in
 * compliance with the License.  You may obtain a copy of the
 * License at:
 *
 *      https://www.gnu.org/licenses/agpl-3.0.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.  See the License for the specific
 * language governing permissions and limitations under the
 * License.
 */
import ContextError from './ContextError';

export default class ErrorResponse {

    constructor(response) {
        this.response = response;
    }

    get status() {
        return this.response.status;
    }

    isContextError() {
        return this.response.data && this.response.data.context && this.response.data.message;
    }

    asContextError() {
        if (this.isContextError()) {
            return new ContextError(this.response.data.context, this.response.data.message);
        }
        if (this.response.data && this.response.data.message) {
            return new ContextError('entity', this.response.data.message);
        }
        return new ContextError('entity', 'Unexpected error occurred. No details about the nature of the error were provided');
    }

    isBadRequest() {
        return this.status === 400;
    }
}
